# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkEdit(Model):
    """BenchmarkEdit.

    :param benchmark_category_id: benchmark category Id <span
     class='property-internal'>Required</span>
    :type benchmark_category_id: int
    :param benchmark_info: benchmark name <span
     class='property-internal'>Required</span>
    :type benchmark_info: str
    """

    _validation = {
        'benchmark_category_id': {'required': True},
        'benchmark_info': {'required': True},
    }

    _attribute_map = {
        'benchmark_category_id': {'key': 'benchmarkCategoryId', 'type': 'int'},
        'benchmark_info': {'key': 'benchmarkInfo', 'type': 'str'},
    }

    def __init__(self, benchmark_category_id, benchmark_info):
        super(BenchmarkEdit, self).__init__()
        self.benchmark_category_id = benchmark_category_id
        self.benchmark_info = benchmark_info
