# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkValue(Model):
    """BenchmarkValue.

    :param benchmark_value_id: Indicator for which benchmark factor
    :type benchmark_value_id: int
    :param begin_date: Begin Date for the benchmark factor
    :type begin_date: datetime
    :param end_date: End Date for the benchmark factor
    :type end_date: datetime
    :param value: Value set for the benchmark factor
    :type value: float
    """

    _attribute_map = {
        'benchmark_value_id': {'key': 'benchmarkValueId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, benchmark_value_id=None, begin_date=None, end_date=None, value=None):
        super(BenchmarkValue, self).__init__()
        self.benchmark_value_id = benchmark_value_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.value = value
